@@ -1,6 +1,6 @@
 package Mason::t::Filters;
 BEGIN {
-  $Mason::t::Filters::VERSION = '2.14';
+  $Mason::t::Filters::VERSION = '2.15';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
@@ -282,4 +282,31 @@ hello world!
     );
 }
 
+sub test_filter_comment : Tests {
+    my $self = shift;
+    $self->test_comp(
+        src => '
+<%class>
+method LESSp () { sub { uc(shift) } }
+</%class>
+% $.LESSp {{
+#header {
+    text-align: left;
+}
+% }}
+#footer {
+    text-align: right;
+}
+',
+        expect => '
+#HEADER {
+    TEXT-ALIGN: LEFT;
+}
+#footer {
+    text-align: right;
+}
+',
+    );
+}
+
 1;
